require 'spec_helper'
require 'core_helper'

class TestBucket < TestCore
  def test_get
    bucket = RSimperium::Bucket.new(@app_id, get_auth_token, gen_uuid)
    bucket.post('item1', 'x' => 1)
    assert_equal({'x' => 1}, bucket.get('item1').data)
  end

  def test_index
    bucket = RSimperium::Bucket.new(@app_id, get_auth_token, gen_uuid)
    3.times {|i| bucket.post "item#{i}", 'x' => i}

    got = bucket.index(:limit => 2).data
    want = {
      :current => got['current'],
      :mark => got['mark'],
      :index => [
        # Index items should be ordered with most recently modified first
        {:id => 'item2', :v => 1}.stringify_keys!,
        {:id => 'item1', :v => 1}.stringify_keys!,
      ],
    }.stringify_keys!

    assert_equal want, got

    got2 = bucket.index(:limit => 2, :mark => got['mark']).data
    want2 = {
      :current => got['current'],
      :index => [
        {:id => 'item0', :v => 1}.stringify_keys!
      ],
    }.stringify_keys!

    assert_equal want, got
  end

  def test_post
    bucket = RSimperium::Bucket.new(@app_id, get_auth_token, gen_uuid)
    response = bucket.post 'item-1', { :x => 1 }
    assert_equal 1, response.meta.version
  end
end
